@@ -7,7 +7,7 @@ with_mock_API({
     expect_equal(nrow(res), 10)
   })
   test_that("detailed check", {
-    res <- full_text("Oregon", type = "10-K", name = "Intel")
+    res <- full_text("\"Transition Report\"", type = "10-K", name = "Intel")
     expect_length(res, 9)
     expect_true(nrow(res) == 3 || nrow(res) == 4)
     expect_equal(sum(res$cik == 50863), nrow(res))
